@@ -1,9 +1,9 @@
 from dataclasses import dataclass
-from multiprocessing import AuthenticationError
 
 @dataclass(frozen=False)
 class ChargerOptions:
-    powerswitch_controls_charging: bool
-    ampmeter_is_attribute: bool
+    powerswitch_controls_charging: bool = False
+    charger_is_outlet: bool = False
+    ampmeter_is_attribute: bool = False
     powermeter_factor: int = 1
     authentication_required: bool = False
\ No newline at end of file
