@@ -13,7 +13,8 @@ class ChargerSwitch(HubMember):
             initval,
             currentname: str,
             ampmeter_is_attribute: bool,
-            hubdata=None
+            hubdata=None,
+            init_override:bool = False
     ):
         self._hubdata = hubdata
         self._hass = hass
@@ -21,7 +22,7 @@ class ChargerSwitch(HubMember):
         self._current = None
         self._current_attr_name = currentname
         self._ampmeter_is_attribute = ampmeter_is_attribute
-        super().__init__(data_type, listenerentity, initval)
+        super().__init__(data_type=data_type, listenerentity=listenerentity, init_override=init_override, initval=initval)
 
     @property
     def is_initialized(self) -> bool:
